[Libreoffice-commits] core.git: include/svx svx/source

Noel Grandin (via logerrit) logerrit at kemper.freedesktop.org
Thu Feb 11 06:58:15 UTC 2021


 include/svx/obj3d.hxx           |    2 +-
 include/svx/scene3d.hxx         |    2 +-
 include/svx/svdoashp.hxx        |    2 +-
 include/svx/svdobj.hxx          |    2 +-
 include/svx/svdocapt.hxx        |    2 +-
 include/svx/svdocirc.hxx        |    2 +-
 include/svx/svdoedge.hxx        |    2 +-
 include/svx/svdograf.hxx        |    2 +-
 include/svx/svdomeas.hxx        |    2 +-
 include/svx/svdopath.hxx        |    2 +-
 include/svx/svdorect.hxx        |    2 +-
 include/svx/svdotable.hxx       |    2 +-
 include/svx/svdotext.hxx        |    2 +-
 include/svx/svdovirt.hxx        |    2 +-
 svx/source/engine3d/obj3d.cxx   |    4 ++--
 svx/source/engine3d/scene3d.cxx |    6 +++---
 svx/source/svdraw/svdoashp.cxx  |    4 ++--
 svx/source/svdraw/svdobj.cxx    |    4 ++--
 svx/source/svdraw/svdocapt.cxx  |    4 ++--
 svx/source/svdraw/svdocirc.cxx  |    4 ++--
 svx/source/svdraw/svdoedge.cxx  |    4 ++--
 svx/source/svdraw/svdograf.cxx  |    4 ++--
 svx/source/svdraw/svdomeas.cxx  |    4 ++--
 svx/source/svdraw/svdopath.cxx  |    4 ++--
 svx/source/svdraw/svdorect.cxx  |    4 ++--
 svx/source/svdraw/svdotext.cxx  |    4 ++--
 svx/source/svdraw/svdovirt.cxx  |    4 ++--
 svx/source/table/svdotable.cxx  |    4 ++--
 28 files changed, 43 insertions(+), 43 deletions(-)

New commits:
commit 5128bf29d5febceaec51854595f23ae487a0cdec
Author:     Noel Grandin <noel at peralex.com>
AuthorDate: Wed Feb 10 15:26:59 2021 +0200
Commit:     Noel Grandin <noel.grandin at collabora.co.uk>
CommitDate: Thu Feb 11 07:57:25 2021 +0100

    rename RestGeoData->RestoreGeoData
    
    Change-Id: I5d584f40949e5c7f2fc7e126cd9cae81eed4db70
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/110708
    Tested-by: Jenkins
    Reviewed-by: Noel Grandin <noel.grandin at collabora.co.uk>

diff --git a/include/svx/obj3d.hxx b/include/svx/obj3d.hxx
index 4f18b4fcf694..0cbaa62ef3ee 100644
--- a/include/svx/obj3d.hxx
+++ b/include/svx/obj3d.hxx
@@ -129,7 +129,7 @@ public:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void          SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void          RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void          RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     // get/set the selection
     bool GetSelected() const { return mbIsSelected; }
diff --git a/include/svx/scene3d.hxx b/include/svx/scene3d.hxx
index bd1c31ea13ca..4c8b1b14a7e2 100644
--- a/include/svx/scene3d.hxx
+++ b/include/svx/scene3d.hxx
@@ -132,7 +132,7 @@ public:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void          SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void          RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void          RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     virtual void NbcSetTransform(const basegfx::B3DHomMatrix& rMatrix) override;
     virtual void SetTransform(const basegfx::B3DHomMatrix& rMatrix) override;
diff --git a/include/svx/svdoashp.hxx b/include/svx/svdoashp.hxx
index 8b12de0d2ec2..65540e93a9d5 100644
--- a/include/svx/svdoashp.hxx
+++ b/include/svx/svdoashp.hxx
@@ -230,7 +230,7 @@ public:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData &rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData &rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData &rGeo) override;
 
     // need to take fObjectRotation instead of aGeo.nAngle, replace it temporary
     virtual bool TRGetBaseGeometry(basegfx::B2DHomMatrix& rMatrix, basegfx::B2DPolyPolygon& rPolyPolygon) const override;
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index f38f201621e7..88c00569ab67 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -922,7 +922,7 @@ protected:
     /// SdrObjGeoData.
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo);
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo);
 
     // internal versions
     const SfxItemSet& GetObjectItemSet() const;
diff --git a/include/svx/svdocapt.hxx b/include/svx/svdocapt.hxx
index 0b2563878384..2805a147a5cf 100644
--- a/include/svx/svdocapt.hxx
+++ b/include/svx/svdocapt.hxx
@@ -133,7 +133,7 @@ public:
 private:
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
 public:
     virtual SdrObjectUniquePtr DoConvertToPolyObj(bool bBezier, bool bAddText) const override;
diff --git a/include/svx/svdocirc.hxx b/include/svx/svdocirc.hxx
index 81687cc0bfe2..a13eeac0e241 100644
--- a/include/svx/svdocirc.hxx
+++ b/include/svx/svdocirc.hxx
@@ -134,7 +134,7 @@ public:
 private:
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 public:
     Degree100 GetStartAngle() const { return nStartAngle; }
     Degree100 GetEndAngle() const { return nEndAngle; }
diff --git a/include/svx/svdoedge.hxx b/include/svx/svdoedge.hxx
index 18842c0620e5..fe09104dbc4e 100644
--- a/include/svx/svdoedge.hxx
+++ b/include/svx/svdoedge.hxx
@@ -268,7 +268,7 @@ public:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     /** updates edges that are connected to the edges of this object
         as if the connected objects send a repaint broadcast
diff --git a/include/svx/svdograf.hxx b/include/svx/svdograf.hxx
index 88ebc776537b..950bb00b6cd5 100644
--- a/include/svx/svdograf.hxx
+++ b/include/svx/svdograf.hxx
@@ -187,7 +187,7 @@ public:
     virtual void            NbcMirror(const Point& rRef1, const Point& rRef2) override;
     virtual std::unique_ptr<SdrObjGeoData>  NewGeoData() const override;
     virtual void            SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void            RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void            RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     bool                    HasGDIMetaFile() const;
 
diff --git a/include/svx/svdomeas.hxx b/include/svx/svdomeas.hxx
index b3dc1cd56666..74c473e09e76 100644
--- a/include/svx/svdomeas.hxx
+++ b/include/svx/svdomeas.hxx
@@ -70,7 +70,7 @@ protected:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     // protected destructor
     virtual ~SdrMeasureObj() override;
diff --git a/include/svx/svdopath.hxx b/include/svx/svdopath.hxx
index b825f1413630..b934d74d3e46 100644
--- a/include/svx/svdopath.hxx
+++ b/include/svx/svdopath.hxx
@@ -131,7 +131,7 @@ public:
 private:
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
 public:
     virtual SdrObjectUniquePtr DoConvertToPolyObj(bool bBezier, bool bAddText) const override;
diff --git a/include/svx/svdorect.hxx b/include/svx/svdorect.hxx
index 65671216da41..f10105db87ba 100644
--- a/include/svx/svdorect.hxx
+++ b/include/svx/svdorect.hxx
@@ -57,7 +57,7 @@ protected:
     /// instance with new and assigning it to mpXPoly.
     virtual void RecalcXPoly();
     const XPolygon& GetXPoly() const;
-    virtual void           RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void           RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     // protected destructor
     virtual ~SdrRectObj() override;
diff --git a/include/svx/svdotable.hxx b/include/svx/svdotable.hxx
index ef52185b8116..59299425d2b1 100644
--- a/include/svx/svdotable.hxx
+++ b/include/svx/svdotable.hxx
@@ -269,7 +269,7 @@ private:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     SdrOutliner* GetCellTextEditOutliner( const sdr::table::Cell& rCell ) const;
 
diff --git a/include/svx/svdotext.hxx b/include/svx/svdotext.hxx
index 72ebffcbc5e3..8d013d77ec8c 100644
--- a/include/svx/svdotext.hxx
+++ b/include/svx/svdotext.hxx
@@ -292,7 +292,7 @@ protected:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
     void NbcSetEckenradius(tools::Long nRad);
 
     // #115391# new method for SdrObjCustomShape and SdrTextObj to correctly handle and set
diff --git a/include/svx/svdovirt.hxx b/include/svx/svdovirt.hxx
index 420fb6caed26..d4fdd821acf3 100644
--- a/include/svx/svdovirt.hxx
+++ b/include/svx/svdovirt.hxx
@@ -45,7 +45,7 @@ protected:
 
     virtual std::unique_ptr<SdrObjGeoData> NewGeoData() const override;
     virtual void SaveGeoData(SdrObjGeoData& rGeo) const override;
-    virtual void RestGeoData(const SdrObjGeoData& rGeo) override;
+    virtual void RestoreGeoData(const SdrObjGeoData& rGeo) override;
 
     // protected destructor
     virtual ~SdrVirtObj() override;
diff --git a/svx/source/engine3d/obj3d.cxx b/svx/source/engine3d/obj3d.cxx
index 0cc2ac83df20..c770a751018a 100644
--- a/svx/source/engine3d/obj3d.cxx
+++ b/svx/source/engine3d/obj3d.cxx
@@ -421,12 +421,12 @@ void E3dObject::SaveGeoData(SdrObjGeoData& rGeo) const
     static_cast<E3DObjGeoData &>(rGeo).maTransformation = maTransformation;
 }
 
-void E3dObject::RestGeoData(const SdrObjGeoData& rGeo)
+void E3dObject::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
     maLocalBoundVol = static_cast<const E3DObjGeoData &>(rGeo).maLocalBoundVol;
     E3DModifySceneSnapRectUpdater aUpdater(this);
     NbcSetTransform(static_cast<const E3DObjGeoData &>(rGeo).maTransformation);
-    SdrAttrObj::RestGeoData (rGeo);
+    SdrAttrObj::RestoreGeoData (rGeo);
 }
 
 // 2D-rotation of a 3D-body, normally this is done by the scene itself.
diff --git a/svx/source/svdraw/svdoashp.cxx b/svx/source/svdraw/svdoashp.cxx
index 01be2eae9798..fd5b0c3082c5 100644
--- a/svx/source/svdraw/svdoashp.cxx
+++ b/svx/source/svdraw/svdoashp.cxx
@@ -2894,9 +2894,9 @@ void SdrObjCustomShape::SaveGeoData(SdrObjGeoData& rGeo) const
         *pAny >>= rAGeo.aAdjustmentSeq;
 }
 
-void SdrObjCustomShape::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrObjCustomShape::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrTextObj::RestGeoData( rGeo );
+    SdrTextObj::RestoreGeoData( rGeo );
     const SdrAShapeObjGeoData& rAGeo=static_cast<const SdrAShapeObjGeoData&>(rGeo);
     fObjectRotation = rAGeo.fObjectRotation;
     SetMirroredX( rAGeo.bMirroredX );
diff --git a/svx/source/svdraw/svdobj.cxx b/svx/source/svdraw/svdobj.cxx
index 986b390301ce..dad689840f04 100644
--- a/svx/source/svdraw/svdobj.cxx
+++ b/svx/source/svdraw/svdobj.cxx
@@ -1880,7 +1880,7 @@ void SdrObject::SaveGeoData(SdrObjGeoData& rGeo) const
     }
 }
 
-void SdrObject::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrObject::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
     SetRectsDirty();
     aOutRect      =rGeo.aBoundRect    ;
@@ -1917,7 +1917,7 @@ std::unique_ptr<SdrObjGeoData> SdrObject::GetGeoData() const
 void SdrObject::SetGeoData(const SdrObjGeoData& rGeo)
 {
     tools::Rectangle aBoundRect0; if (pUserCall!=nullptr) aBoundRect0=GetLastBoundRect();
-    RestGeoData(rGeo);
+    RestoreGeoData(rGeo);
     SetChanged();
     BroadcastObjectChange();
     SendUserCall(SdrUserCallType::Resize,aBoundRect0);
diff --git a/svx/source/svdraw/svdocapt.cxx b/svx/source/svdraw/svdocapt.cxx
index 3d8ee8a8088f..2ef316fe14fe 100644
--- a/svx/source/svdraw/svdocapt.cxx
+++ b/svx/source/svdraw/svdocapt.cxx
@@ -667,9 +667,9 @@ void SdrCaptionObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rCGeo.aTailPoly=aTailPoly;
 }
 
-void SdrCaptionObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrCaptionObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrRectObj::RestGeoData(rGeo);
+    SdrRectObj::RestoreGeoData(rGeo);
     const SdrCaptObjGeoData& rCGeo=static_cast<const SdrCaptObjGeoData&>(rGeo);
     aTailPoly=rCGeo.aTailPoly;
 }
diff --git a/svx/source/svdraw/svdocirc.cxx b/svx/source/svdraw/svdocirc.cxx
index 58d61d05ce9a..57801461bd18 100644
--- a/svx/source/svdraw/svdocirc.cxx
+++ b/svx/source/svdraw/svdocirc.cxx
@@ -956,9 +956,9 @@ void SdrCircObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rCGeo.nEndAngle  =nEndAngle;
 }
 
-void SdrCircObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrCircObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrRectObj::RestGeoData(rGeo);
+    SdrRectObj::RestoreGeoData(rGeo);
     const SdrCircObjGeoData& rCGeo=static_cast<const SdrCircObjGeoData&>(rGeo);
     nStartAngle=rCGeo.nStartAngle;
     nEndAngle  =rCGeo.nEndAngle;
diff --git a/svx/source/svdraw/svdoedge.cxx b/svx/source/svdraw/svdoedge.cxx
index ca319d65487e..5231d0649b3f 100644
--- a/svx/source/svdraw/svdoedge.cxx
+++ b/svx/source/svdraw/svdoedge.cxx
@@ -2478,9 +2478,9 @@ void SdrEdgeObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rEGeo.aEdgeInfo      =aEdgeInfo;
 }
 
-void SdrEdgeObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrEdgeObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrTextObj::RestGeoData(rGeo);
+    SdrTextObj::RestoreGeoData(rGeo);
     const SdrEdgeObjGeoData& rEGeo=static_cast<const SdrEdgeObjGeoData&>(rGeo);
     if (aCon1.pObj!=rEGeo.aCon1.pObj) {
         if (aCon1.pObj!=nullptr) aCon1.pObj->RemoveListener(*this);
diff --git a/svx/source/svdraw/svdograf.cxx b/svx/source/svdraw/svdograf.cxx
index b11aea46a41a..f7a03a82278d 100644
--- a/svx/source/svdraw/svdograf.cxx
+++ b/svx/source/svdraw/svdograf.cxx
@@ -813,9 +813,9 @@ void SdrGrafObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rGGeo.bMirrored=bMirrored;
 }
 
-void SdrGrafObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrGrafObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrRectObj::RestGeoData(rGeo);
+    SdrRectObj::RestoreGeoData(rGeo);
     const SdrGrafObjGeoData& rGGeo=static_cast<const SdrGrafObjGeoData&>(rGeo);
     bMirrored=rGGeo.bMirrored;
 }
diff --git a/svx/source/svdraw/svdomeas.cxx b/svx/source/svdraw/svdomeas.cxx
index a83fe8ad38b5..5bf412089ee1 100644
--- a/svx/source/svdraw/svdomeas.cxx
+++ b/svx/source/svdraw/svdomeas.cxx
@@ -1121,9 +1121,9 @@ void SdrMeasureObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rMGeo.aPt2=aPt2;
 }
 
-void SdrMeasureObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrMeasureObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrTextObj::RestGeoData(rGeo);
+    SdrTextObj::RestoreGeoData(rGeo);
     const SdrMeasureObjGeoData& rMGeo=static_cast<const SdrMeasureObjGeoData&>(rGeo);
     aPt1=rMGeo.aPt1;
     aPt2=rMGeo.aPt2;
diff --git a/svx/source/svdraw/svdopath.cxx b/svx/source/svdraw/svdopath.cxx
index 58c389142754..aea01d2d279d 100644
--- a/svx/source/svdraw/svdopath.cxx
+++ b/svx/source/svdraw/svdopath.cxx
@@ -2715,9 +2715,9 @@ void SdrPathObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rPGeo.meKind=meKind;
 }
 
-void SdrPathObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrPathObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrTextObj::RestGeoData(rGeo);
+    SdrTextObj::RestoreGeoData(rGeo);
     const SdrPathObjGeoData& rPGeo=static_cast<const SdrPathObjGeoData&>(rGeo);
     maPathPolygon=rPGeo.maPathPolygon;
     meKind=rPGeo.meKind;
diff --git a/svx/source/svdraw/svdorect.cxx b/svx/source/svdraw/svdorect.cxx
index c6185e54624b..60ee002f1f54 100644
--- a/svx/source/svdraw/svdorect.cxx
+++ b/svx/source/svdraw/svdorect.cxx
@@ -569,9 +569,9 @@ void SdrRectObj::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
     SetXPolyDirty(); // because of the corner radius
 }
 
-void SdrRectObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrRectObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    SdrTextObj::RestGeoData(rGeo);
+    SdrTextObj::RestoreGeoData(rGeo);
     SetXPolyDirty();
 }
 
diff --git a/svx/source/svdraw/svdotext.cxx b/svx/source/svdraw/svdotext.cxx
index 4ba4996ae6dd..518dc88cf1af 100644
--- a/svx/source/svdraw/svdotext.cxx
+++ b/svx/source/svdraw/svdotext.cxx
@@ -1448,9 +1448,9 @@ void SdrTextObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rTGeo.aGeo   =aGeo;
 }
 
-void SdrTextObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrTextObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 { // RectsDirty is called by SdrObject
-    SdrAttrObj::RestGeoData(rGeo);
+    SdrAttrObj::RestoreGeoData(rGeo);
     const SdrTextObjGeoData& rTGeo=static_cast<const SdrTextObjGeoData&>(rGeo);
     NbcSetLogicRect(rTGeo.aRect);
     aGeo   =rTGeo.aGeo;
diff --git a/svx/source/svdraw/svdovirt.cxx b/svx/source/svdraw/svdovirt.cxx
index 42d78aa69a97..552eb438b755 100644
--- a/svx/source/svdraw/svdovirt.cxx
+++ b/svx/source/svdraw/svdovirt.cxx
@@ -488,9 +488,9 @@ void SdrVirtObj::SaveGeoData(SdrObjGeoData& rGeo) const
     rRefObj.SaveGeoData(rGeo);
 }
 
-void SdrVirtObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrVirtObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
-    rRefObj.RestGeoData(rGeo);
+    rRefObj.RestoreGeoData(rGeo);
     SetRectsDirty();
 }
 
diff --git a/svx/source/table/svdotable.cxx b/svx/source/table/svdotable.cxx
index 2f73ac60d7cd..2d70a85264d6 100644
--- a/svx/source/table/svdotable.cxx
+++ b/svx/source/table/svdotable.cxx
@@ -2374,13 +2374,13 @@ void SdrTableObj::SaveGeoData(SdrObjGeoData& rGeo) const
 }
 
 
-void SdrTableObj::RestGeoData(const SdrObjGeoData& rGeo)
+void SdrTableObj::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
     DBG_ASSERT( dynamic_cast< const TableObjectGeoData* >( &rGeo ), "svx::SdrTableObj::SaveGeoData(), illegal geo data!" );
 
     maLogicRect = static_cast<const TableObjectGeoData &>(rGeo).maLogicRect;
 
-    SdrTextObj::RestGeoData (rGeo);
+    SdrTextObj::RestoreGeoData (rGeo);
 
     if( mpImpl.is() )
         mpImpl->LayoutTable(maRect, false, false);


More information about the Libreoffice-commits mailing list
diff --git a/svx/source/engine3d/scene3d.cxx b/svx/source/engine3d/scene3d.cxx
index 799157460817..5b09cd9660f8 100644
--- a/svx/source/engine3d/scene3d.cxx
+++ b/svx/source/engine3d/scene3d.cxx
@@ -509,11 +509,11 @@ void E3dScene::SaveGeoData(SdrObjGeoData& rGeo) const
     static_cast<E3DSceneGeoData &>(rGeo).aCamera = aCamera;
 }
 
-void E3dScene::RestGeoData(const SdrObjGeoData& rGeo)
+void E3dScene::RestoreGeoData(const SdrObjGeoData& rGeo)
 {
     // #i94832# removed E3DModifySceneSnapRectUpdater here.
-    // It should not be needed, is already part of E3dObject::RestGeoData
-    E3dObject::RestGeoData (rGeo);
+    // It should not be needed, is already part of E3dObject::RestoreGeoData
+    E3dObject::RestoreGeoData (rGeo);
     SetCamera (static_cast<const E3DSceneGeoData &>(rGeo).aCamera);
 }
 